XRoute class

Annotate the main widget of a route

isRoot is set false by default. This flag indicates that this route is a new page rather than a component of a parent route's widget. If isRoot is set to true, then go_router's default transition is used. If you want to modify the transition behaviour, then you can annotate your GoRouteData with XTransition.

Constructors

XRoute({bool isRoot = false, bool isLayout = false, Page<T> buildPage<T>(BuildContext context, Widget child, GoRouterState state)?})
const

Properties

buildPage Page<T> Function<T>(BuildContext context, Widget child, GoRouterState state)?
Custom page builder. Users can instantiate their own CustomTransitionPage here. beatx provides a default widget through builder. You can use builder directly or you can create your own child widget.
final
hashCode int
The hash code for this object.
no setterinherited
isLayout bool
** Not yet supported ** If the widget is not a page but a layout, you can set this to true. Default value is false.
final
isRoot bool
If the widget is not the sub page, but a new root you can set this to true. Default value is false.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited