isLayout property
** Not yet supported **
If the widget is not a page but a layout,
you can set this to true.
Default value is false.
Implementation
final bool isLayout;
** Not yet supported **
If the widget is not a page but a layout,
you can set this to true.
Default value is false.
final bool isLayout;