isRoot property
If the widget is not the sub page, but a new root
you can set this to true.
Default value is false.
Implementation
final bool isRoot;
If the widget is not the sub page, but a new root
you can set this to true.
Default value is false.
final bool isRoot;